#!/bin/sh
#
#                      Petals CLI Bootstrap Script
#
# Environment variables:
#
#	JAVA_HOME		Directory containing the JRE. Use the java executable
#					found in $PATH if not defined.
#
#	JAVA_OPTS		Options for the JVM. Try "java -h" to get informations
#					about the available options for your environment
#
#############################################################################

#Test symbolic link 
if [ -h $0 ];then
	CUR_DIR=$(dirname $(readlink $0))
else
	CUR_DIR=`dirname $0`
fi

# Set the path to the java executable
JAVA="$JAVA_HOME/bin/java"
[ -x "$JAVA" ] || JAVA="`which java`" || {
	echo "ERROR: java executable not found" >&2
	exit 1
}


# Set the path to bootstrap jar
PETALS_CLI_JAR="${CUR_DIR}/../lib/petals-cli.jar"
[ -f "$PETALS_CLI_JAR" ] || {
	echo "ERROR: petals-cli.jar: the jar archive was not found" >&2
	exit 1
}

PETALS_CLI_CLASSPATH=$PETALS_CLI_JAR

# Add installed Petals CLI extensions to the classpath
PETALS_CLI_EXTENSIONS=`ls -1 $CUR_DIR/../extensions/*.jar 2>/dev/null`
for EXTENSION in $PETALS_CLI_EXTENSIONS
do
	PETALS_CLI_CLASSPATH=$PETALS_CLI_CLASSPATH:$EXTENSION
done

# Add default preferences file to the classpath
PETALS_CLI_CLASSPATH=$PETALS_CLI_CLASSPATH:$CUR_DIR/../conf

# Adapt patches if the architecture is Cygwin
case "`uname`" in
	CYGWIN*)
		JAVA="`cygpath --unix "$JAVA"`"
		if [ "$PETALS_HOME" != "" ];
		then
			PETALS_HOME="`cygpath --unix "$PETALS_HOME"`"
		fi
		PETALS_CLASSPATH="`cygpath --unix "$PETALS_CLASSPATH"`"
		;;
esac

# Set an potential user preference file
USER_PREFS=$HOME/.petals-cli/petals-cli.default
if [ -f "$USER_PREFS" ];
then
   # A user preference file exists, it is used.
   export PETALS_CLI_PREFS="$USER_PREFS"
fi

# Start
exec "$JAVA" -classpath $PETALS_CLI_CLASSPATH $JAVA_OPTS -Djline.shutdownhook=true org.ow2.petals.cli.Main "$@"
