/**
 * Copyright (c) 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.log;

import java.util.logging.Formatter;
import java.util.logging.Level;
import java.util.logging.LogRecord;

/**
 * A {@link LogRecord} formatter to print error message of Petals CLI.
 * @author Christophe DENEUX - Linagora
 */
public class PetalsCliFormatter extends Formatter {

    /**
     * Format the given LogRecord.
     *
     * @param record
     *            the log record to be formatted.
     * @return a formatted log record
     */
    @Override
	public synchronized String format(LogRecord record) {
        final StringBuffer sb = new StringBuffer();

        final Level level = record.getLevel();
        if (level.equals(Level.SEVERE)) {
            sb.append("ERROR");
        } else {
            sb.append(level.getLocalizedName());
        }
        sb.append(": ");
        sb.append(formatMessage(record));
        sb.append(System.getProperty( "line.separator" ));

        return sb.toString();
    }

}
