/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.shell;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;

import org.ow2.petals.cli.api.exception.ShellException;

/**
 * This class is the shell implementation for petals CLI for file scripting use
 * 
 * @author Christophe DENEUX - Linagora
 */
public class PetalsFileScriptShell extends PetalsScriptShell {

    /**
     * The name of the file containing commands to execute
     */
    private final String filename;

    /**
     * @param filename
     *            The name of the file containing commands to execute
     * @param argv
     * @param isDebugModeEnable
     *            Flag indicating if the debug mode is enable.
     * @param isYesFlagEnable
     *            Flag to enable the automatic confirmation
     */
    public PetalsFileScriptShell(final String filename, final String[] argv,
            final boolean isDebugModeEnable, final boolean isYesFlagEnable) {
        super(argv, isDebugModeEnable, isYesFlagEnable);
        this.filename = filename;
    }

    @Override
    protected InputStream getCommandStream() throws ShellException {
        try {
            return new FileInputStream(this.filename);
        } catch (final FileNotFoundException e) {
            throw new ShellException(e);
        }
    }


}
