/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.shell.command;

import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.PrintStream;

import org.ow2.petals.cli.api.command.exception.CommandBadArgumentNumberException;
import org.ow2.petals.cli.api.command.exception.CommandException;

public class SystemCall extends AbstractCommand {

    public SystemCall() {
        super("system");
        this.setUsage("usage: system <systemcommand> <systemcommand_arg0> <systemcommand_arg1> ...");
        this.setDescription("Execute system command");
    }

    @Override
    public void execute(String[] args) throws CommandException {

        String toExecute = "";
        final String osName = System.getProperty("os.name");
        if (osName != null && osName.toLowerCase().contains("win"))
            toExecute += "cmd /c ";

        if (args.length > 0) {
        	toExecute += args[ 0 ];

            try {
                final Process process = Runtime.getRuntime().exec(toExecute);
                final BufferedInputStream stdout = new BufferedInputStream(process.getInputStream());
                try {
                    final PrintStream ps = this.getShell().getPrintStream();
                    int c;
                    while ((c = stdout.read()) != -1) {
                        ps.write(c);
                    }

                    final int exitCode = process.waitFor();

                    this.getShell().setExitStatus(exitCode);

                } finally {
                    stdout.close();
                }
            } catch (final IOException e) {
                throw new CommandException(this, e);
            } catch (final InterruptedException e) {
                throw new CommandException(this, e);
            }
        } else {
            throw new CommandBadArgumentNumberException(this);
        }

    }

}
