/**
 * Copyright (c) 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.shell.command;

import org.apache.commons.cli.Option;
import org.apache.commons.cli.OptionBuilder;
import org.apache.commons.cli.OptionGroup;
import org.apache.commons.cli.Options;
import org.ow2.petals.cli.api.command.CommandUtil;
import org.ow2.petals.cli.api.command.exception.CommandException;


/**
 * A test command without argument that fails on execution
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class CommandExecutedWithError extends AbstractCommand {

    public static final String DUMMY_SHORT_OPTION = "d";

    static final String DUMMY_LONG_OPTION = "dummy";

    private static final Option DUMMY_OPTION = OptionBuilder.isRequired(true)
            .withLongOpt(DUMMY_LONG_OPTION).withDescription("Dummy option.")
            .create(DUMMY_SHORT_OPTION);

    private final CommandResult cmdRes;

    public CommandExecutedWithError(final CommandResult cmdRes) {
        super();
        this.cmdRes = cmdRes;
        this.setUsage(CommandUtil.formatCommandUsage(this));
    }

    @Override
    public void execute(String[] args) throws CommandException {

        cmdRes.setExecuted(true);

        throw new CommandException(this, "Execution always failed !!");
    }

    @Override
    public Options createOptions() {
        Options options = new Options();
        OptionGroup op = new OptionGroup();
        op.addOption(DUMMY_OPTION);
        options.addOptionGroup(op);
        return options;
    }
}