/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.shell.command;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import org.junit.Test;
import org.ow2.petals.cli.api.command.exception.CommandBadArgumentNumberException;
import org.ow2.petals.cli.api.command.exception.CommandException;
import org.ow2.petals.cli.api.exception.ShellException;

/**
 *
 * @author "Mathieu CARROLLE - EBM WebSourcing"
 *
 */
public class SystemCallTest extends AbstractArtifactCommandTest {

    /**
     * Test that the command usage is defined
     */
    @Test
    public void testUsage_0() {

        final DummyShellWrapper dummyShell = new DummyShellWrapper();
        final SystemCall command = new SystemCall();
        command.setShell(dummyShell.getShell());
        final String usage = command.getUsage();
        assertNotNull("Command usage null", usage);
        assertFalse("Command usage empty", usage.isEmpty());
        assertTrue("'usage' is missing at the begining of the command usage",
                usage.startsWith("usage"));
        assertTrue("The command name is missing in the command usage",
                usage.contains(command.getName()));
    }

    /**
     * Test of the command "system" against argument management, where:
     * <ul>
     * <li>no option is provided</li>
     * </ul>
     * </p>
     * <p>
     * Expected results: an error occurs about bad argument number.
     * </p>
     * 
     * @see <a
     *      href="http://jira.petalslink.com/browse/PETALSESBCLI-74">PETALSESBCLI-74</a>
     */
    @Test(expected = CommandBadArgumentNumberException.class)
    public void testArgumentsError_0() throws CommandException {
        final DummyShellWrapper dummyShell = new DummyShellWrapper();
        final SystemCall command = new SystemCall();
        command.setShell(dummyShell.getShell());

        command.execute(new String[] {});
    }

    @Test
    public void testExecute() throws ShellException, CommandException {
        String expected = "linux";
        DummyShellWrapper dummyShell = new DummyShellWrapper();
        SystemCall command = new SystemCall();
        command.setShell(dummyShell.getShell());
        command.execute( new String[]{ "echo " + expected });
        assertEquals(expected + System.getProperty("line.separator"), dummyShell.getOut().toString());
        assertEquals(0, dummyShell.getShell().getExitStatus());
    }

    @Test
    public void testExecuteWithErrorExitStatus() throws ShellException, CommandException {

    	String cmd;
    	String osName = System.getProperty( "os.name" );
    	if( osName != null
    			&& osName.toLowerCase().contains( "win" ))
    		cmd = "dir .\\lol31";
    	else
    		cmd = "ls /linuxrockstoto";

        DummyShellWrapper dummyShell = new DummyShellWrapper();
        SystemCall command = new SystemCall();
        command.setShell(dummyShell.getShell());
        command.execute( new String[] { cmd });

        assertTrue(0 != dummyShell.getShell().getExitStatus());
    }
}
