/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.shell.command;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import java.io.ByteArrayOutputStream;
import java.io.PrintStream;

import org.junit.Test;
import org.ow2.petals.admin.ContainerAdministrationMock;
import org.ow2.petals.cli.api.command.exception.CommandException;
import org.ow2.petals.cli.api.connection.AuthenticatedConnectionParameters;
import org.ow2.petals.cli.api.exception.ShellException;
import org.ow2.petals.cli.shell.PetalsCli;

/**
 *
 * @author "Mathieu CARROLLE - EBM WebSourcing"
 *
 */
public class VersionTest extends AbstractArtifactCommandTest {

    /**
     * Test that the command usage is defined
     */
    @Test
    public void testUsage_0() {

        final DummyShellWrapper dummyShell = new DummyShellWrapper();
        final Version command = new Version();
        command.setShell(dummyShell.getShell());
        final String usage = command.getUsage();
        assertNotNull("Command usage null", usage);
        assertFalse("Command usage empty", usage.isEmpty());
        assertTrue("'usage' is missing at the begining of the command usage",
                usage.startsWith("usage"));
        assertTrue("The command name is missing in the command usage",
                usage.contains(command.getName()));
    }

    @Test
    public void testExecute() throws ShellException, CommandException {

        final PrintStream standardConsoleOut = System.out;
        final PrintStream standardConsoleError = System.err;

        try {
            final ByteArrayOutputStream outBAIS = new ByteArrayOutputStream();
            System.setOut(new PrintStream(outBAIS));
            final ByteArrayOutputStream errBAIS = new ByteArrayOutputStream();
            System.setErr(new PrintStream(errBAIS));

            final Version command = new Version();
            final PetalsCli shell = new PetalsCli(new String[] { command.getName() }, false, true);
            shell.registersCommand(command);
            shell.setConnectionParameters(new AuthenticatedConnectionParameters("localhost", 7700,
                    "petals", "petals", null));
            command.setShell(shell);

            shell.run();

            final String error = errBAIS.toString();
            final String output = outBAIS.toString();
            assertTrue("An error message is printed", error.isEmpty());
            assertEquals(
                    ContainerAdministrationMock.SYSTEM_INFO + System.getProperty("line.separator"),
                    output);
            assertEquals("Unexpected exit code", 0, shell.getExitStatus());

        } finally {
            System.setOut(standardConsoleOut);
            System.setErr(standardConsoleError);
        }

    }
}
